@@ -1,7 +1,7 @@
 GetQualifications <-
 getquals <-
 function (qual, status = NULL, return.all = TRUE, pagenumber = 1, 
-    pagesize = 100, verbose = getOption('MTurkR.verbose'), ...) {
+    pagesize = 100, verbose = getOption('MTurkR.verbose', TRUE), ...) {
     # temporary check for `print` argument (remove after v1.0)
     if('print' %in% names(list(...)) && is.null(verbose))
         verbose <- list(...)$print
