@@ -35,43 +35,41 @@ function (statistic, period = "LifeToDate", count = NULL, response.group = NULL,
     request$statistic <- statistic
     request$period <- period
     if(request$valid == TRUE) {
-        if(!is.null(count) & period == "OneDay") {
-            request$value <- setNames(data.frame(matrix(nrow = count, ncol = 2)),
-                                    c("Date", "Value"))
+        if(period == "OneDay" && !is.null(count)) {
+            request$value <- setNames(data.frame(matrix(nrow = count, ncol = 3)), c("Date", "Value", "Statistic"))
+            request$value$Statistic <- statistic
             for (i in 1:count) {
-                request$value[i, 1] <- strsplit(strsplit(request$xml, 
-                    "<Date>")[[1]][2], "</Date>")[[1]][1]
-                if(statistic %in% value.long) 
-                    request$value[i, 2] <- strsplit(strsplit(request$xml, 
-                    "<LongValue>")[[1]][2], "</LongValue>")[[1]][1]
-                else if(statistic %in% value.double) 
-                    request$value[i, 2] <- strsplit(strsplit(request$xml, 
-                    "<DoubleValue>")[[1]][2], "</DoubleValue>")[[1]][1]
-                else
+                request$value[i, 1] <- strsplit(strsplit(request$xml, "<Date>")[[1]][2], "</Date>")[[1]][1]
+                if(statistic %in% value.long) {
+                    request$value[i, 2] <- strsplit(strsplit(request$xml, "<LongValue>")[[1]][2], "</LongValue>")[[1]][1]
+                } else if(statistic %in% value.double) {
+                    request$value[i, 2] <- strsplit(strsplit(request$xml, "<DoubleValue>")[[1]][2], "</DoubleValue>")[[1]][1]
+                } else {
                     warning("Cannot print statistic value")
+                }
             }
             if(verbose) {
-                message("Statistic (", statistic, ", past ", count, 
-                    " days) Retrieved: ", request$value)
+                if(as.numeric(count) == 1)
+                    message("Statistic (", statistic, ", past ", count, " days) Retrieved: ", request$value$Value[1])
+                else
+                    message("Statistic (", statistic, ", past ", count, " days) Retrieved")
+            }
+        } else {
+            request$value <- setNames(data.frame(matrix(nrow = 1, ncol = 3)), c("Date", "Value", "Statistic"))
+            request$value$Statistic <- statistic
+            request$value$Date <- strsplit(strsplit(request$xml, "<Date>")[[1]][2], "</Date>")[[1]][1]
+            if(statistic %in% value.long) {
+                request$value$Value <- strsplit(strsplit(request$xml, "<LongValue>")[[1]][2], "</LongValue>")[[1]][1]
+            } else if(statistic %in% value.double) {
+                request$value$Value <- strsplit(strsplit(request$xml, "<DoubleValue>")[[1]][2], "</DoubleValue>")[[1]][1]
             }
-        }
-        else {
-            request$date <- strsplit(strsplit(request$xml, 
-                "<Date>")[[1]][2], "</Date>")[[1]][1]
-            if(statistic %in% value.long) 
-                request$value <- strsplit(strsplit(request$xml, 
-                "<LongValue>")[[1]][2], "</LongValue>")[[1]][1]
-            else if(statistic %in% value.double) 
-                request$value <- strsplit(strsplit(request$xml, 
-                "<DoubleValue>")[[1]][2], "</DoubleValue>")[[1]][1]
             if(verbose) 
-                message(statistic, " (", period, "): ", request$value)
+                message(statistic, " (", period, "): ", request$value$Value[1])
         }
         return(request$value)
-    }
-    else if(request$valid == FALSE){
+    } else {
         if(verbose)
             warning("Invalid Request")
-        return(NULL)
+        return(setNames(data.frame(matrix(nrow = 0, ncol = 3)), c("Date", "Value", "Statistic")))
     }
 }
