@@ -1,7 +1,10 @@
 SetHITAsReviewing <-
 reviewing <-
-function (hit = NULL, hit.type = NULL, revert = FALSE, 
-    verbose = getOption('MTurkR.verbose'), ...){
+function(hit = NULL, 
+         hit.type = NULL, 
+         annotation = NULL,
+         revert = FALSE, 
+         verbose = getOption('MTurkR.verbose', TRUE), ...){
     # temporary check for `print` argument (remove after v1.0)
     if('print' %in% names(list(...)) && is.null(verbose))
         verbose <- list(...)$print
@@ -10,21 +13,26 @@ function (hit = NULL, hit.type = NULL, revert = FALSE,
         revert <- "true"
     else
         revert <- "false"
-    if((is.null(hit) & is.null(hit.type)) | (!is.null(hit) & !is.null(hit.type))) 
-        stop("Must provide 'hit' xor 'hit.type'")
-    else if(!is.null(hit)){
+    if((is.null(hit) & is.null(hit.type) & is.null(annotation)) | 
+       (!is.null(hit) & !is.null(hit.type) & !is.null(annotation))) {
+        stop("Must provide 'hit' xor 'hit.type' xor 'annotation'")
+    } else if(!is.null(hit)){
         if(is.factor(hit))
             hit <- as.character(hit)
         hitlist <- hit
-    }
-    else if(!is.null(hit.type)) {
+    } else if(!is.null(hit.type)) {
         if(is.factor(hit.type))
             hit.type <- as.character(hit.type)
         hitsearch <- SearchHITs(verbose = FALSE, return.qual.dataframe = FALSE, ...)
         hitlist <- hitsearch$HITs$HITId[hitsearch$HITs$HITTypeId %in% hit.type]
-        if(length(hitlist) == 0) 
-            stop("No HITs found for HITType")
+    } else if(!is.null(annotation)) {
+        if(is.factor(annotation))
+            annotation <- as.character(annotation)
+        hitsearch <- SearchHITs(verbose = FALSE, return.qual.dataframe = FALSE, ...)
+        hitlist <- hitsearch$HITs$HITId[hitsearch$HITs$RequesterAnnotation %in% annotation]
     }
+    if(length(hitlist) == 0) 
+        stop("No HITs found for HITType")
     GETparameters <- paste("&Revert=", revert, sep = "")
     HITs <- data.frame(matrix(ncol = 3, nrow=length(hitlist)))
     names(HITs) <- c("HITId", "Status", "Valid")
